@echo off
REM
REM Fendl.bat: Process nuclear data files for FENDL library
REM
REM Author: D. L. Aldama, IAEA Consultant
REM Date: 11/2004
REM
REM Description: It runs NJOY code for generating the ACE and
REM              MATXS files of FENDL.
REM              It can perform the calculation for a selected
REM              number of materials or for all materials for which
REM              the NJOY input options are saved on the %fendlinp%
REM              directory.
REM
REM Notes: The names of the files should be 5 character lenght with
REM        the format XXaaa, where XX is the chemical symbol and
REM        aaa represents a 3 digit A number.
REM        Examples: H001, H003, Be009, B010, Bi209 , Fe056
REM        Extension *.nji is assumed and should not be entered.
REM
REM        The following enviroment variables must be defined:
REM         njoy99: Directory Containing the NJOY executable
REM         fendlinp: Directory cointaining the NJOY input files (*.nji)
REM          fendle: Directory containing the merged FENDL/E libraries:
REM                  - Fendle21.dat for neutrons
REM                  - Fendlep.dat for photo-atomic data
REM         fendlmc: Directory for ACE and XSDIR files (from ACER)
REM         fendlmg: Directory for multigroup files (from GROUPR,
REM                  GAMINR and MATXSR)
REM         fendlout: Directory for NJOY output files
REM         fendlprg: Directory containing FENDL the called batch
REM                   procedures and programs.
REM
REM Called procedures: NJOYR.bat (on fendlprg )
REM Called programs: UpdXSDIR (on fendlprg, used by NJOYR.bat)
REM                  njoy (on njoy99)
REM
REM Usage: fendl [p1] [p2] ....[pn]
REM        where p1, p2, pn optional NJOY input files names
REM         without extension (*.nji is assumed)
REM        If no parameter is entered all the *.nji (NJOY input options)
REM        files saved on fendlinp directory are processed.
REM
REM   1.) Runs one material with NJOY input file H001.nji:
REM        fendl H001
REM
REM   2.) Runs several materials
REM        fendl H001 H002 H003 Be009 B010 B011 Li006 Li007 BI209
REM
REM   3.) Run all *.nji files on fendlinp directory
REM         fendl
REM
REM
REM Setting FENDLE environment
REM
    set njoy99=\aldama\njoy99\
    set fendlinp=\aldama\FENDL21\Fendlnji21\
    set fendle=\aldama\fendl21\Fendle21\
    set fendlmc=\aldama\fendl21\Fendlmc21\
    set fendlmg=\aldama\fendl21\Fendlmg21\
    set fendlout=\aldama\fendl21\Fendlout\
    set fendlprg=\aldama\fendl21\Fendlprg\
REM
REM Header
REM
   echo ***** Processing Nuclear Data Files for FENDL *****
   date/T
   time/T 
REM
REM Copying evaluated nuclear data libraries from %fendle% directoty
REM
    echo.
    echo Getting evaluated nuclear data files from %fendle% ...
    if not exist TAPE20 copy %fendle%Fendle21.dat TAPE20
    if not exist TAPE40 copy %fendle%Fendlep.dat  TAPE40
REM
REM Running NJOY for FENDL
REM
    if exist nji.inp del nji.inp
    if %1.==.    goto doall
    if %1.==all. goto doall
:while
    echo %1 >>nji.inp
    shift
    if %1.==. goto exec
    goto while
:doall
    dir /B/OD %fendlinp%*.nji >nji.inp
:exec
    for /F "delims=. " %%i in (nji.inp) do call %fendlprg%NjoyR %%i
    if exist nji.inp del nji.inp
    set njoy99=
    set fendlinp=
    set fendle=
    set fendlmc=
    set fendlmg=
    set fendlout=
    set fendlprg=
REM
REM Done
REM
    echo.
    date/T
    time/T
    echo ***** Job ended *****  